Monthly calendar | Australian Bureau of Statistics

Search ABS
Release calendar

# Future release - May 2026

### May 2026

The next 6 months of future releases are available. Release dates may change. All times are in Canberra time.

Sunday | Monday | Tuesday | Wednesday | Thursday | Friday | Saturday
--- | --- | --- | --- | --- | --- | ---
26 | 27 | 28 | 29 | 30 | 1 | 2
|  |  |  |  | Producer Price Indexes, Australia March 2026 - 11:30am View current release Contains a range of producer price indexes in the Australian economy, comprising mining, manufacturing, construction and service industries Updated information National Aboriginal and Torres Strait Islander Nutrition and Physical Activity Survey 2023 - 11:30am View current release Additional information on measured physical activity, inactivity, and sleep in Australia Microdata: National Aboriginal and Torres Strait Islander Nutrition and Physical Activity Survey Australia - 11:30am First release Presents microdata from the 2023 NATSINPAS, including dietary intake, physical activity and sleep. |
3 | 4 | 5 | 6 | 7 | 8 | 9
| Life expectancy by Socio-Economic Indexes for Areas (SEIFA) 2011-2024 - 11:30am First release Life expectancy and life tables for Index of Relative Socio-economic Advantage and Disadvantage deciles. Building Approvals, Australia March 2026 - 11:30am View current release Provides the number of dwelling units and value of buildings approved | Understanding ABS productivity statistics May 2026 - 11:30am First release A guide to productivity measures and their role in economic analysis. Monthly Household Spending Indicator March 2026 - 11:30am View current release Monthly and quarterly estimates of household spending | Selected Living Cost Indexes, Australia March 2026 - 11:30am View current release Living Cost Indexes (LCIs) measures the price change of goods and services and its effect on living expenses of selected household types International Investment Position, Australia: Supplementary Statistics 2025 - 11:30am View current release Supplementary statistics on Australia s international investment position by counterpart countries General Social Survey: Summary Results, Australia 2025 - 11:30am View current release Provides data on the social characteristics, wellbeing and social experiences of people in Australia | Updated information Deaths from external causes 2024 - 11:30am View current release This release provides revised Causes of Death statistics for 2022-2024 to reflect new information available since last publication. Updated information Intentional self-harm (suicide) deaths 2024 - 11:30am View current release This release provides revised Causes of Death statistics for 2022-2024 to reflect new information available since last publication. International Trade in Goods March 2026 - 11:30am View current release Statistics about international trade in goods on a balance of payments and international trade basis Updated information Causes of Death, Australia 2024 - 11:30am View current release This release provides revised Causes of Death statistics for 2022-2024 to reflect new information available since last publication. | Research and Experimental Development, Higher Education Organisations, Australia 2024 - 11:30am View current release Contains data on expenditure and human resources devoted to research and development (R&D) carried out by higher education organisations in Australia |
10 | 11 | 12 | 13 | 14 | 15 | 16
| Updated information Building Approvals, Australia March 2026 - 11:30am View current release These data cubes present Building Approvals data for small geographic areas | Overseas Arrivals and Departures, Australia March 2026 - 11:30am View current release Statistics on international travel arriving in and departing from Australia. | Lending Indicators March Quarter 2026 - 11:30am View current release New borrower-accepted finance commitments for housing, personal and business loans Wage Price Index, Australia March 2026 - 11:30am View current release The WPI measures wage inflation and includes statistics about price change for wages and salaries. |  |  |
17 | 18 | 19 | 20 | 21 | 22 | 23
|  | Livestock products March 2026 - 11:30am View current release Quarterly statistics on livestock slaughtering (numbers and value) and meat production. | Monthly Employee Earnings Indicator March 2026 - 11:30am View current release Experimental estimates of employee earnings and jobs, sourced from Single Touch Payroll (STP) data | Labour Force, Australia April 2026 - 11:30am View current release Headline estimates of employment, unemployment, underemployment, participation and hours worked from the monthly Labour Force Survey |  |
24 | 25 | 26 | 27 | 28 | 29 | 30
|  | Updated information Data by region 2011-25 - 11:30am Updates to Data by region including new 2025 data across various topics Great Barrier Reef Ecosystem Accounts, experimental estimates 2022-23 financial year - 11:30am First release The first set of experimental Ecosystem Accounts for the Great Barrier Reef region, encompassing terrestrial, coastal, and marine realms. Business Conditions and Sentiments May 2026 - 11:30am View current release Insights into business sentiments | Consumer Price Index, Australia April 2026 - 11:30am View current release The Consumer Price Index (CPI) measures price inflation of goods and services purchased by Australian households in each capital city. Construction Work Done, Australia, Preliminary March 2026 - 11:30am View current release Provides preliminary estimates of value of total construction work done, building work done and engineering construction work done | Monthly Household Spending Indicator April 2026 - 11:30am View current release Monthly and quarterly estimates of household spending Private New Capital Expenditure and Expected Expenditure, Australia March 2026 - 11:30am View current release Quarterly statistics about actual and expected private new capex investment spend on buildings and equipment by industry. | Deaths due to acute respiratory infections in Australia April 2026 - 11:30am View current release Acute respiratory disease mortality in Australia Provisional Mortality Statistics Jan - Feb 2026 - 11:30am View current release Provisional deaths data for measuring changes in patterns of mortality during the COVID-19 pandemic in Australia |
31 | 1 | 2 | 3 | 4 | 5 | 6

Back to top of the page